@@ -2,11 +2,10 @@ use 5.008001;
 use strict;
 no strict 'refs';
 use warnings;
-no warnings 'once';
 
 package Class::Tiny;
 # ABSTRACT: Minimalist class construction
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.013'; # VERSION
 
 use Carp ();
 
@@ -79,7 +78,7 @@ sub get_all_attribute_defaults_for {
 
 package Class::Tiny::Object;
 # ABSTRACT: Base class for classes built with Class::Tiny
-our $VERSION = '0.011'; # VERSION
+our $VERSION = '0.013'; # VERSION
 
 my ( %LINEAR_ISA_CACHE, %BUILD_CACHE, %DEMOLISH_CACHE, %CAN_CACHE );
 
@@ -163,7 +162,7 @@ __END__
 
 =pod
 
-=encoding utf-8
+=encoding UTF-8
 
 =head1 NAME
 
@@ -171,7 +170,7 @@ Class::Tiny - Minimalist class construction
 
 =head1 VERSION
 
-version 0.011
+version 0.013
 
 =head1 SYNOPSIS
 
@@ -253,13 +252,13 @@ C<DESTROY> calls C<DEMOLISH> for each class from child to parent
 
 =back
 
+Multiple-inheritance is possible, with superclass order determined via
+L<mro::get_linear_isa|mro/Functions>.
+
 It uses no non-core modules for any recent Perl. On Perls older than v5.10 it
 requires L<MRO::Compat>. On Perls older than v5.14, it requires
 L<Devel::GlobalDestruction>.
 
-=for Pod::Coverage new get_all_attributes_for get_all_attribute_defaults_for
-prepare_class create_attributes
-
 =head1 USAGE
 
 =head2 Defining attributes
@@ -294,9 +293,13 @@ set.  The object is passed as an argument to a code reference.
     use Class::Tiny qw/name id/, {
         title     => 'Peon',
         skills    => sub { [] },
-        hire_date => sub { $_[0]->_build_hire_date }, 
+        hire_date => sub { $_[0]->_build_hire_date },
     };
 
+When subclassing, if multiple accessors of the same name exist in different
+classes, any default (or lack of default) is determined by standard
+method resolution order.
+
 To make your own custom accessors, just pre-declare the method name before
 loading Class::Tiny:
 
@@ -436,6 +439,9 @@ references are cached for speed.  Ensure that all inheritance and methods are
 in place before creating objects. (You don't want to be changing that once you
 create objects anyway, right?)
 
+=for Pod::Coverage new get_all_attributes_for get_all_attribute_defaults_for
+prepare_class create_attributes
+
 =head1 RATIONALE
 
 =head2 Why this instead of Object::Tiny or Class::Accessor or something else?
@@ -448,10 +454,31 @@ L<Object::Tiny> and L<Object::Tiny::RW> were close to what I wanted, but
 lacking some features I deemed necessary, and their maintainers have an even
 more strict philosophy against feature creep than I have.
 
-I looked for something like it on CPAN, but after checking a dozen class
-creators I realized I could implement it exactly how I wanted faster than I
-could search CPAN for something merely sufficient.  Compared to everything
-else, this is smaller in implementation and simpler in API.
+I also considered L<Class::Accessor>, which has been around a long time and is
+heavily used, but it, too, lacked features I wanted and did things in ways I
+considered poor design.
+
+I looked for something else on CPAN, but after checking a dozen class creators
+I realized I could implement exactly what I wanted faster than I could search
+CPAN for something merely sufficient.
+
+In general, compared to most things on CPAN (other than Object::Tiny),
+Class::Tiny is smaller in implementation and simpler in API.
+
+Specifically, here is how Class::Tiny ("C::T") compares to Object::Tiny
+("O::T") and Class::Accessor ("C::A"):
+
+ FEATURE                            C::T    O::T      C::A
+ --------------------------------------------------------------
+ attributes defined via import      yes     yes       no
+ read/write accessors               yes     no        yes
+ lazy attribute defaults            yes     no        no
+ provides new                       yes     yes       yes
+ provides DESTROY                   yes     no        no
+ new takes either hashref or list   yes     no (list) no (hash)
+ new validates arguments            yes     no        no
+ Moo(se)-like BUILD/DEMOLISH        yes     no        no
+ no extraneous methods via @ISA     yes     yes       no
 
 =head2 Why this instead of Moose or Moo?
 
@@ -465,7 +492,7 @@ required.
 By contrast, Class::Tiny has no MOP and has B<zero> non-core dependencies for
 Perls in the L<support window|perlpolicy>.  It has far less code, less
 complexity and no learning curve. If you don't need or can't afford what Moo or
-Moose offer, this is a intended to be a reasonable fallback.
+Moose offer, this is intended to be a reasonable fallback.
 
 That said, Class::Tiny offers Moose-like conventions for things like C<BUILD>
 and C<DEMOLISH> for some minimal interoperability and an easier upgrade path.
@@ -499,6 +526,10 @@ David Golden <dagolden@cpan.org>
 
 =item *
 
+Gelu Lupas <gelu@devnull.ro>
+
+=item *
+
 Karen Etheridge <ether@cpan.org>
 
 =item *
@@ -507,7 +538,7 @@ Matt S Trout <mstrout@cpan.org>
 
 =item *
 
-Olivier Mengu <dolmen@cpan.org>
+Olivier Mengué <dolmen@cpan.org>
 
 =item *
 
